@@ -1,9 +1,17 @@
+"""
+App Config
+"""
+
 from django.apps import AppConfig
 
 from . import __version__
 
 
 class AaThemeConfig(AppConfig):
+    """
+    App config
+    """
+
     name = "aa_theme_slate"
     label = "aa_theme_slate"
     verbose_name = 'Bootstrap Theme "Slate" for Alliance Auth v{version}'.format(
